"""Constant values."""

# Import built-in modules
import logging

# Name of the environment variable that points to a config file to use. If this
# environment variable is not set, we use the 'config.json' file that is
# located in '~/.cragl/smartRescue/config.json'. This configuration file will
# be created on the fly the first time you launch smartRescue. It contains the
# default configuration setup.
CRAGL_SMARTRESCUE_CONFIG_PATH = "CRAGL_SMARTRESCUE_CONFIG_PATH"

# Name of the environment variable that points to the folder that contains the
# Nuke working files that we want to process. If this environment variable is
# not set, we use the package internal 'process' folder.
CRAGL_SMARTRESCUE_PROCESS_PATH = "CRAGL_SMARTRESCUE_PROCESS_PATH"

# Logging level mapping to use for logging when using smartRescue.
LOGGING_LEVEL = {
    "debug": logging.DEBUG,
    "info": logging.INFO,
    "warning": logging.WARNING,
    "error": logging.ERROR,
    "critical": logging.CRITICAL
}

# Choices that we have available when handling nodes in the steps. These items
# will be added to the custom `HandleDropdown` widget.
COMBO_CHOICES = (
    "delete",
    "disable",
    "disconnect",
)

# Name of this package.
NAME = "smartRescue"

# Name of 'steps'key from configuration.
STEPS = "steps"

# Name of 'general' key from configuration.
GENERAL = "general"

# Number of characters building a separator line.
COUNT_SPACER = 100

# Header separator lines.
HEADER = {
    "h1": "=" * COUNT_SPACER,
    "h2": "-" * COUNT_SPACER,
    "h3": "." * COUNT_SPACER,
}

# Format to use for logging.
LOGGING_FORMAT = "%(name)s [%(levelname)s]: %(message)s"

# Regex pattern to use for doc string extraction.
# We use this pattern to extract the one liner header, the body, the standard
# examples and the advanced examples from the steps module doc strings.
# https://regex101.com/r/d1N0Je/1
DOCSTRING_EXTRACTION_PATTERN = (r"(?P<description>.*Examples:).*Standard:"
                                r"(?P<example_standard>.*).*Advanced:"
                                r"(?P<example_advanced>.*)")

# Home page of cragl.
CRAGL_HOME_URL = "http://www.cragl.com"

# Path to the smartRescue documentation.
DOCS_URL = ("http://www.cragl.com/tools/smartRescue/documentation/html/"
            "index.html")
