"""Show the user interface."""

# Import local modules
import sys

# Import third-party modules
try:
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtWidgets

# Import local modules
from smartRescue.mvc import controller
from smartRescue.mvc import model
from smartRescue.mvc import view

# View instance to use.
_VIEW = None


def show(standalone):
    """Show the ui and connect to controller.

    Args:
        standalone (bool, optional): If True, run the main window in standalone
            mode, otherwise it is run via a DCC.

    """
    app = QtWidgets.QApplication.instance()
    if not app:
        app = QtWidgets.QApplication(sys.argv)

    # We need to make this global in here otherwise Nuke won't show the
    # window.
    global _VIEW  # pylint: disable=global-statement
    _VIEW = view.View()
    _VIEW.raise_()
    _VIEW.show()

    model_ = model.Model()
    controller.Controller(_VIEW, model_, standalone)

    app.exec_()
